summaryrefslogtreecommitdiffstats
path: root/src/include/usr/isteps
diff options
context:
space:
mode:
authorRichard J. Knight <rjknight@us.ibm.com>2012-10-26 12:34:46 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2012-11-15 09:57:35 -0600
commit7e9680f99f9dccf871b364f034f1eb19e9a1ae30 (patch)
tree259da5ff97d113ce61190923e1f231480d216195 /src/include/usr/isteps
parentb8d95068b788c0f1b1587996ef2852df7d338f37 (diff)
downloadtalos-hostboot-7e9680f99f9dccf871b364f034f1eb19e9a1ae30.tar.gz
talos-hostboot-7e9680f99f9dccf871b364f034f1eb19e9a1ae30.zip
Updates to IPL flow to match doc v1.18
Change-Id: I9fe83e777fde516b6ddbadd2eea4969b87e601fa RTC: 50424 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/2167 Reviewed-by: Brian H. Horton <brianh@linux.ibm.com> Tested-by: Jenkins Server Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/include/usr/isteps')
-rw-r--r--src/include/usr/isteps/istep06list.H31
-rw-r--r--src/include/usr/isteps/istep07list.H32
-rw-r--r--src/include/usr/isteps/istep08list.H2
-rw-r--r--src/include/usr/isteps/istep09list.H57
-rw-r--r--src/include/usr/isteps/istep10list.H142
-rw-r--r--src/include/usr/isteps/istep11list.H47
-rw-r--r--src/include/usr/isteps/istep12list.H20
-rw-r--r--src/include/usr/isteps/istep13list.H48
-rw-r--r--src/include/usr/isteps/istep14list.H44
-rw-r--r--src/include/usr/isteps/istep15list.H9
-rw-r--r--src/include/usr/isteps/istep16list.H46
-rw-r--r--src/include/usr/isteps/istep18list.H23
-rw-r--r--src/include/usr/isteps/istep21list.H70
13 files changed, 388 insertions, 183 deletions
diff --git a/src/include/usr/isteps/istep07list.H b/src/include/usr/isteps/istep07list.H
index c9645f8cc..44dd0083f 100644
--- a/src/include/usr/isteps/istep07list.H
+++ b/src/include/usr/isteps/istep07list.H
@@ -28,17 +28,19 @@
* @file istep07list.H
*
* IStep 07 Nest Chiplets
- * IPL FLow Doc v1.03 (06/26/12)
+ * IPL FLow Doc v1.18 (10/18/12)
*
- * 07.1 proc_a_x_pci_dmi_pll_setup
+ * 07.1 proc_a_x_pci_dmi_pll_initf
+ * : PLL Initfile for A, X, PCIe, DMI
+ * 07.2 proc_a_x_pci_dmi_pll_setup
* : Setup PLL for A, X, PCIe, DMI
- * 07.2 proc_startclock_chiplets
+ * 07.3 proc_startclock_chiplets
* : Start clocks on A, X, PCIe chiplets
- * 07.3 proc_chiplet_scominit
+ * 07.4 proc_chiplet_scominit
* : Apply scom inits to chiplets
- * 07.4 proc_pcie_scominit
+ * 07.5 proc_pcie_scominit
* : Apply scom inits to PCIe chiplets
- * 07.5 proc_scomoverride_chiplets
+ * 07.6 proc_scomoverride_chiplets
* : Apply sequenced scom inits
*
* *****************************************************************
@@ -69,9 +71,17 @@ namespace INITSERVICE
EXT_IMAGE,
}
},
+ {
+ ISTEPNAME(07,01,"proc_a_x_pci_dmi_pll_initf"),
+ NEST_CHIPLETS::call_proc_a_x_pci_dmi_pll_initf,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
{
- ISTEPNAME(07,01,"proc_a_x_pci_dmi_pll_setup"),
+ ISTEPNAME(07,02,"proc_a_x_pci_dmi_pll_setup"),
NEST_CHIPLETS::call_proc_a_x_pci_dmi_pll_setup,
{
START_FN,
@@ -81,7 +91,7 @@ namespace INITSERVICE
{
- ISTEPNAME(07,02,"proc_startclock_chiplets"),
+ ISTEPNAME(07,03,"proc_startclock_chiplets"),
NEST_CHIPLETS::call_proc_startclock_chiplets,
{
START_FN,
@@ -91,7 +101,7 @@ namespace INITSERVICE
{
- ISTEPNAME(07,03,"proc_chiplet_scominit"),
+ ISTEPNAME(07,04,"proc_chiplet_scominit"),
NEST_CHIPLETS::call_proc_chiplet_scominit,
{
START_FN,
@@ -101,7 +111,7 @@ namespace INITSERVICE
{
- ISTEPNAME(07,04,"proc_pcie_scominit"),
+ ISTEPNAME(07,05,"proc_pcie_scominit"),
NEST_CHIPLETS::call_proc_pcie_scominit,
{
START_FN,
@@ -111,7 +121,7 @@ namespace INITSERVICE
{
- ISTEPNAME(07,05,"proc_scomoverride_chiplets"),
+ ISTEPNAME(07,06,"proc_scomoverride_chiplets"),
NEST_CHIPLETS::call_proc_scomoverride_chiplets,
{
START_FN,
diff --git a/src/include/usr/isteps/istep08list.H b/src/include/usr/isteps/istep08list.H
index b029a328f..54b90aeab 100644
--- a/src/include/usr/isteps/istep08list.H
+++ b/src/include/usr/isteps/istep08list.H
@@ -28,7 +28,7 @@
* @file istep08list.H
*
* IStep 08 EDI, EI Initialization
- * IPL FLow Doc v1.08 (08/13/12)
+ * IPL FLow Doc v1.18 (10/18/12)
*
* 08.1 fabric_erepair
* : Restore Fabric/EDI Bus eRepair data
diff --git a/src/include/usr/isteps/istep09list.H b/src/include/usr/isteps/istep09list.H
index 37b7190e2..55ceaba80 100644
--- a/src/include/usr/isteps/istep09list.H
+++ b/src/include/usr/isteps/istep09list.H
@@ -1,25 +1,25 @@
-// IBM_PROLOG_BEGIN_TAG
-// This is an automatically generated prolog.
-//
-// $Source: src/include/usr/isteps/istep09list.H $
-//
-// IBM CONFIDENTIAL
-//
-// COPYRIGHT International Business Machines Corp. 2012
-//
-// p1
-//
-// Object Code Only (OCO) source materials
-// Licensed Internal Code Source Materials
-// IBM HostBoot Licensed Internal Code
-//
-// The source code for this program is not published or other-
-// wise divested of its trade secrets, irrespective of what has
-// been deposited with the U.S. Copyright Office.
-//
-// Origin: 30
-//
-// IBM_PROLOG_END
+/* IBM_PROLOG_BEGIN_TAG */
+/* This is an automatically generated prolog. */
+/* */
+/* $Source: src/include/usr/isteps/istep09list.H $ */
+/* */
+/* IBM CONFIDENTIAL */
+/* */
+/* COPYRIGHT International Business Machines Corp. 2012 */
+/* */
+/* p1 */
+/* */
+/* Object Code Only (OCO) source materials */
+/* Licensed Internal Code Source Materials */
+/* IBM HostBoot Licensed Internal Code */
+/* */
+/* The source code for this program is not published or otherwise */
+/* divested of its trade secrets, irrespective of what has been */
+/* deposited with the U.S. Copyright Office. */
+/* */
+/* Origin: 30 */
+/* */
+/* IBM_PROLOG_END_TAG */
#ifndef __ISTEPS_ISTEP09LIST_H
#define __ISTEPS_ISTEP09LIST_H
@@ -28,11 +28,14 @@
* @file istep09list.H
*
* IStep 09 Activate PowerBus
- * IPL FLow Doc v1.01 (03/26/12)
+ * IPL FLow Doc v1.18 (10/18/12)
*
* 09.1 proc_build_smp
* : Integrate PgP Islands into SMP
*
+ * 09.2 host_slave_sbe_update
+ * : placeholder for secure boot
+ *
* *****************************************************************
* THIS FILE WAS GENERATED ON 2012-04-11:1607
* *****************************************************************
@@ -70,6 +73,14 @@ namespace INITSERVICE
EXT_IMAGE,
}
},
+ {
+ ISTEPNAME(09,02,"host_slave_sbe_update"),
+ ACTIVATE_POWERBUS::call_host_slave_sbe_update,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
// END OF LIST!
diff --git a/src/include/usr/isteps/istep10list.H b/src/include/usr/isteps/istep10list.H
index 824681e93..8b287e679 100644
--- a/src/include/usr/isteps/istep10list.H
+++ b/src/include/usr/isteps/istep10list.H
@@ -29,15 +29,42 @@
* @file istep10list.H
*
* Step 10 Hostboot SBE Centaur Init
- * IPL FLow Doc v1.01 (03/26/12)
+ * IPL FLow Doc v1.18 (10/10/12)
*
+ * 10.1 host_PRD_hwreconfig
+ * : Hook for PRD to handle reconfig
+ * 10.2 cen_sbe_istep_pnor
+ * : TP Chiplet init
+ * 10.3 cen_sbe_tp_chiplet_init1
+ * : TP Chiplet init
+ * 10.4 cen_sbe_npll_initf
+ * : Program Nest PLL
+ * 10.5 cen_sbe_tp_chiplet_init2
+ * : Cen TP Chiplet init 2
+ * 10.6 cen_sbe_tp_arrayinit
+ * : Cen TP Chiplet array init
+ * 10.7 cen_sbe_tp_chiplet_init3
+ * : Cen TP Chiplet Start clocks
+ * 10.8 cen_sbe_chiplet_init
+ * : Cen Chiplet Init
+ * 10.9 cen_sbe_arrayinit
+ * : Chiplet arrayinit
+ * 10.10 cen_sbe_dts_init
+ * : Cen DTS init
+ * 10.11 cen_sbe_initf
+ * : Cen Scan overrides
+ * 10.12 cen_sbe_do_manual_inits
+ * : Manual Cen Scans
+ * 10.13 cen_sbe_nest_startclocks
+ * : Start Cen Nest
+ * 10.14 cen_sbe_scominits
+ * : Perform any Cen scom inits
+
* Please see the note in initsvcstructs.H for description of
* the ISTEPNAME macro.
*
*/
-
-
#include <initservice/initsvcstructs.H>
#include <initservice/initsvcreasoncodes.H>
@@ -58,13 +85,120 @@ const TaskInfo g_istep10[] = {
}
},
{
- ISTEPNAME(10,01,"cen_sbe_tp_chiplet_init1"),
+ ISTEPNAME(10,01,"host_PRD_hwreconfig"),
+ HWAS::host_PRD_hwreconfig,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+
+ {
+ ISTEPNAME(10,02,"cen_sbe_istep_pnor"),
SBE_CENTAUR_INIT::call_sbe_centaur_init,
{
START_FN,
EXT_IMAGE,
}
},
+ {
+ ISTEPNAME(10,03,"cen_sbe_tp_chiplet_init1"),
+ HWAS::host_stub,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+ {
+ ISTEPNAME(10,04,"cen_sbe_npll_initf"),
+ HWAS::host_stub,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+ {
+ ISTEPNAME(10,05,"cen_sbe_tp_chiplet_init2"),
+ HWAS::host_stub,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+ {
+ ISTEPNAME(10,06,"cen_sbe_tp_arrayinit"),
+ HWAS::host_stub,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+ {
+ ISTEPNAME(10,07,"cen_sbe_tp_chiplet_init3"),
+ HWAS::host_stub,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+ {
+ ISTEPNAME(10,08,"cen_sbe_chiplet_init"),
+ HWAS::host_stub,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+ {
+ ISTEPNAME(10,09,"cen_sbe_tp_arrayinit"),
+ HWAS::host_stub,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+ {
+ ISTEPNAME(10,10,"cen_sbe_dts_init"),
+ HWAS::host_stub,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+ {
+ ISTEPNAME(10,11,"cen_sbe_initf"),
+ HWAS::host_stub,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+ {
+ ISTEPNAME(10,12,"cen_sbe_do_manual_inits"),
+ HWAS::host_stub,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+ {
+ ISTEPNAME(10,13,"cen_sbe_nest_startclocks"),
+ HWAS::host_stub,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+ {
+
+ ISTEPNAME(10,14,"cen_sbe_scominits"),
+ HWAS::host_stub,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+
// END OF LIST!
};
diff --git a/src/include/usr/isteps/istep11list.H b/src/include/usr/isteps/istep11list.H
index 31b174de2..142f8308a 100644
--- a/src/include/usr/isteps/istep11list.H
+++ b/src/include/usr/isteps/istep11list.H
@@ -1,32 +1,31 @@
-/* IBM_PROLOG_BEGIN_TAG
- * This is an automatically generated prolog.
- *
- * $Source: src/include/usr/isteps/istep11list.H $
- *
- * IBM CONFIDENTIAL
- *
- * COPYRIGHT International Business Machines Corp. 2011-2012
- *
- * p1
- *
- * Object Code Only (OCO) source materials
- * Licensed Internal Code Source Materials
- * IBM HostBoot Licensed Internal Code
- *
- * The source code for this program is not published or other-
- * wise divested of its trade secrets, irrespective of what has
- * been deposited with the U.S. Copyright Office.
- *
- * Origin: 30
- *
- * IBM_PROLOG_END_TAG
- */
+/* IBM_PROLOG_BEGIN_TAG */
+/* This is an automatically generated prolog. */
+/* */
+/* $Source: src/include/usr/isteps/istep11list.H $ */
+/* */
+/* IBM CONFIDENTIAL */
+/* */
+/* COPYRIGHT International Business Machines Corp. 2011,2012 */
+/* */
+/* p1 */
+/* */
+/* Object Code Only (OCO) source materials */
+/* Licensed Internal Code Source Materials */
+/* IBM HostBoot Licensed Internal Code */
+/* */
+/* The source code for this program is not published or otherwise */
+/* divested of its trade secrets, irrespective of what has been */
+/* deposited with the U.S. Copyright Office. */
+/* */
+/* Origin: 30 */
+/* */
+/* IBM_PROLOG_END_TAG */
#ifndef __ISTEPS_ISTEP11LIST_H
#define __ISTEPS_ISTEP11LIST_H
/**
* list of functions called for DMI Training - ISTEP 11 according to Dean's
- * HostBoot IPL Flow v1.08
+ * IPL Flow Doc v1.18 (10/18/12)
*
* 11.1. dmi_scominit
* : Scom setup on centaur
diff --git a/src/include/usr/isteps/istep12list.H b/src/include/usr/isteps/istep12list.H
index 0fce06b7a..28d2d5b02 100644
--- a/src/include/usr/isteps/istep12list.H
+++ b/src/include/usr/isteps/istep12list.H
@@ -28,15 +28,13 @@
* @file istep12list.H
*
* IStep 12 Step 12 MC Config
- * IPL FLow Doc v1.08 (08/13/12)
+ * IPL FLow Doc v1.18 (10/18/12)
*
* 12.1 host_collect_dimm_spd
* : Collect Master dimm SPD
- * 12.2 mss_volt
- * : Calc dimm voltage
- * 12.3 mss_freq
+ * 12.2 mss_freq
* : Calc dimm frequency
- * 12.4 mss_eff_config
+ * 12.3 mss_eff_config
* : Determine effective config
*
* *****************************************************************
@@ -76,15 +74,7 @@ const TaskInfo g_istep12[] = {
}
},
{
- ISTEPNAME(12,02,"mss_volt"),
- MC_CONFIG::call_mss_volt,
- {
- START_FN,
- EXT_IMAGE,
- }
- },
- {
- ISTEPNAME(12,03,"mss_freq"),
+ ISTEPNAME(12,02,"mss_freq"),
MC_CONFIG::call_mss_freq,
{
START_FN,
@@ -92,7 +82,7 @@ const TaskInfo g_istep12[] = {
}
},
{
- ISTEPNAME(12,04,"mss_eff_config"),
+ ISTEPNAME(12,03,"mss_eff_config"),
MC_CONFIG::call_mss_eff_config,
{
START_FN,
diff --git a/src/include/usr/isteps/istep13list.H b/src/include/usr/isteps/istep13list.H
index fe982d0e9..5f4a627d9 100644
--- a/src/include/usr/isteps/istep13list.H
+++ b/src/include/usr/isteps/istep13list.H
@@ -28,27 +28,29 @@
* @file istep13list.H
*
* IStep 13 Step 13 DRAM Training
- * IPL FLow Doc v1.08 (08/13/12)
+ * IPL FLow Doc v1.18 (10/18/12)
*
* 13.1 host_disable_vddr
* : Disable VDDR on CanContinue loops
- * 13.2 mem_pll_setup
+ * 13.2 mem_pll_initf
+ * : PLL Initfile for MBAs
+ * 13.3 mem_pll_setup
* : Setup PLL for MBAs
- * 13.3 mem_startclocks
+ * 13.4 mem_startclocks
* : Start clocks on MBAs
- * 13.4 host_enable_vddr
+ * 13.5 host_enable_vddr
* : Enable the VDDR3 Voltage Rail
- * 13.5 mss_scominit
+ * 13.6 mss_scominit
* : Perform scom inits to MC and PHY
- * 13.6 mss_ddr_phy_reset
+ * 13.7 mss_ddr_phy_reset
* : Soft reset of DDR PHY macros
- * 13.7 mss_draminit
+ * 13.8 mss_draminit
* : Dram initialize
- * 13.8 mss_draminit_training
+ * 13.9 mss_draminit_training
* : Dram training
- * 13.9 mss_draminit_trainadv
+ * 13.10 mss_draminit_trainadv
* : Advanced dram training
- * 13.10 mss_draminit_mc
+ * 13.11 mss_draminit_mc
* : Hand off control to MC
*
* *****************************************************************
@@ -88,7 +90,15 @@ const TaskInfo g_istep13[] = {
}
},
{
- ISTEPNAME(13,02,"mem_pll_setup"),
+ ISTEPNAME(13,02,"mem_pll_initf"),
+ DRAM_TRAINING::call_mem_pll_initf,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+ {
+ ISTEPNAME(13,03,"mem_pll_setup"),
DRAM_TRAINING::call_mem_pll_setup,
{
START_FN,
@@ -96,7 +106,7 @@ const TaskInfo g_istep13[] = {
}
},
{
- ISTEPNAME(13,03,"mem_startclocks"),
+ ISTEPNAME(13,04,"mem_startclocks"),
DRAM_TRAINING::call_mem_startclocks,
{
START_FN,
@@ -104,7 +114,7 @@ const TaskInfo g_istep13[] = {
}
},
{
- ISTEPNAME(13,04,"host_enable_vddr"),
+ ISTEPNAME(13,05,"host_enable_vddr"),
DRAM_TRAINING::call_host_enable_vddr,
{
START_FN,
@@ -112,7 +122,7 @@ const TaskInfo g_istep13[] = {
}
},
{
- ISTEPNAME(13,05,"mss_scominit"),
+ ISTEPNAME(13,06,"mss_scominit"),
DRAM_TRAINING::call_mss_scominit,
{
START_FN,
@@ -120,7 +130,7 @@ const TaskInfo g_istep13[] = {
}
},
{
- ISTEPNAME(13,06,"mss_ddr_phy_reset"),
+ ISTEPNAME(13,07,"mss_ddr_phy_reset"),
DRAM_TRAINING::call_mss_ddr_phy_reset,
{
START_FN,
@@ -128,7 +138,7 @@ const TaskInfo g_istep13[] = {
}
},
{
- ISTEPNAME(13,07,"mss_draminit"),
+ ISTEPNAME(13,08,"mss_draminit"),
DRAM_TRAINING::call_mss_draminit,
{
START_FN,
@@ -136,7 +146,7 @@ const TaskInfo g_istep13[] = {
}
},
{
- ISTEPNAME(13,08,"mss_draminit_training"),
+ ISTEPNAME(13,09,"mss_draminit_training"),
DRAM_TRAINING::call_mss_draminit_training,
{
START_FN,
@@ -144,7 +154,7 @@ const TaskInfo g_istep13[] = {
}
},
{
- ISTEPNAME(13,09,"mss_draminit_trainadv"),
+ ISTEPNAME(13,10,"mss_draminit_trainadv"),
DRAM_TRAINING::call_mss_draminit_trainadv,
{
START_FN,
@@ -152,7 +162,7 @@ const TaskInfo g_istep13[] = {
}
},
{
- ISTEPNAME(13,10,"mss_draminit_mc"),
+ ISTEPNAME(13,11,"mss_draminit_mc"),
DRAM_TRAINING::call_mss_draminit_mc,
{
START_FN,
diff --git a/src/include/usr/isteps/istep14list.H b/src/include/usr/isteps/istep14list.H
index efd697a3f..6ab917036 100644
--- a/src/include/usr/isteps/istep14list.H
+++ b/src/include/usr/isteps/istep14list.H
@@ -28,24 +28,24 @@
* @file istep14list.H
*
* IStep 14 Dram Initialization
- * IPL FLow Doc v1.08 (08/13/12)
+ * IPL FLow Doc v1.18 (10/18/12)
*
* 14.1 host_startPRD_dram
* : Load PRD for DRAM domain
* 14.2 mss_extent_setup
* MSS Extent Setup
- * 14.3 mss_memdiag
- * Mainstore Pattern Testing
- * 14.4 mss_scrub
+ * 14.3 mss_scrub
* : Start background scrub
- * 14.5 mss_thermal_init
+ * 14.4 mss_thermal_init
* : Initialize the thermal sensor
- * 14.6 proc_setup_bars
+ * 14.5 proc_setup_bars
* : Setup Memory BARs
- * 14.7 proc_pcie_config
+ * 14.6 proc_pcie_config
* : Configure the PHBs
- * 14.8 proc_exit_cache_contained
+ * 14.7 proc_exit_cache_contained
* : Allow execution from memory
+ * 14.8 host_mpipl_service
+ * : Perform MPIPL tasks
*
* *****************************************************************
* THIS FILE WAS GENERATED ON 2012-04-11:1608
@@ -94,11 +94,9 @@ namespace INITSERVICE
EXT_IMAGE,
}
},
-
-
{
- ISTEPNAME(14,03,"mss_memdiag"),
- DRAM_INITIALIZATION::call_mss_memdiag,
+ ISTEPNAME(14,03,"mss_scrub"),
+ DRAM_INITIALIZATION::call_mss_scrub,
{
START_FN,
EXT_IMAGE,
@@ -107,8 +105,8 @@ namespace INITSERVICE
{
- ISTEPNAME(14,04,"mss_scrub"),
- DRAM_INITIALIZATION::call_mss_scrub,
+ ISTEPNAME(14,04,"mss_thermal_init"),
+ DRAM_INITIALIZATION::call_mss_thermal_init,
{
START_FN,
EXT_IMAGE,
@@ -117,8 +115,8 @@ namespace INITSERVICE
{
- ISTEPNAME(14,05,"mss_thermal_init"),
- DRAM_INITIALIZATION::call_mss_thermal_init,
+ ISTEPNAME(14,05,"proc_setup_bars"),
+ DRAM_INITIALIZATION::call_proc_setup_bars,
{
START_FN,
EXT_IMAGE,
@@ -127,8 +125,8 @@ namespace INITSERVICE
{
- ISTEPNAME(14,06,"proc_setup_bars"),
- DRAM_INITIALIZATION::call_proc_setup_bars,
+ ISTEPNAME(14,06,"proc_pcie_config"),
+ DRAM_INITIALIZATION::call_proc_pcie_config,
{
START_FN,
EXT_IMAGE,
@@ -137,18 +135,16 @@ namespace INITSERVICE
{
- ISTEPNAME(14,07,"proc_pcie_config"),
- DRAM_INITIALIZATION::call_proc_pcie_config,
+ ISTEPNAME(14,07,"proc_exit_cache_contained"),
+ DRAM_INITIALIZATION::call_proc_exit_cache_contained,
{
START_FN,
EXT_IMAGE,
}
},
-
-
{
- ISTEPNAME(14,08,"proc_exit_cache_contained"),
- DRAM_INITIALIZATION::call_proc_exit_cache_contained,
+ ISTEPNAME(14,08,"host_mpipl_service"),
+ DRAM_INITIALIZATION::call_host_mpipl_service,
{
START_FN,
EXT_IMAGE,
diff --git a/src/include/usr/isteps/istep15list.H b/src/include/usr/isteps/istep15list.H
index a64579dbc..661ab204a 100644
--- a/src/include/usr/isteps/istep15list.H
+++ b/src/include/usr/isteps/istep15list.H
@@ -28,7 +28,7 @@
* @file istep15list.H
*
* IStep 15 Build Winkle Images
- * IPL FLow Doc v1.08 (08/13/12)
+ * IPL FLow Doc v1.18 (10/18/12)
*
* 15.1 host_build_winkle
* : Build runtime winkle images
@@ -74,8 +74,6 @@ namespace INITSERVICE
EXT_IMAGE,
}
},
-
-
{
ISTEPNAME(15,02,"proc_set_pore_bar"),
BUILD_WINKLE_IMAGES::call_proc_set_pore_bar,
@@ -84,10 +82,9 @@ namespace INITSERVICE
EXT_IMAGE,
}
},
-
{
- ISTEPNAME(15,03,"proc_poreslw_init"),
- BUILD_WINKLE_IMAGES::call_proc_poreslw_init,
+ ISTEPNAME(15,03,"p8_poreslw_init"),
+ BUILD_WINKLE_IMAGES::call_p8_poreslw_init,
{
START_FN,
EXT_IMAGE,
diff --git a/src/include/usr/isteps/istep16list.H b/src/include/usr/isteps/istep16list.H
index 28a1d8de5..d1c978bab 100644
--- a/src/include/usr/isteps/istep16list.H
+++ b/src/include/usr/isteps/istep16list.H
@@ -1,25 +1,25 @@
-// IBM_PROLOG_BEGIN_TAG
-// This is an automatically generated prolog.
-//
-// $Source: src/include/usr/isteps/istep16list.H $
-//
-// IBM CONFIDENTIAL
-//
-// COPYRIGHT International Business Machines Corp. 2012
-//
-// p1
-//
-// Object Code Only (OCO) source materials
-// Licensed Internal Code Source Materials
-// IBM HostBoot Licensed Internal Code
-//
-// The source code for this program is not published or other-
-// wise divested of its trade secrets, irrespective of what has
-// been deposited with the U.S. Copyright Office.
-//
-// Origin: 30
-//
-// IBM_PROLOG_END
+/* IBM_PROLOG_BEGIN_TAG */
+/* This is an automatically generated prolog. */
+/* */
+/* $Source: src/include/usr/isteps/istep16list.H $ */
+/* */
+/* IBM CONFIDENTIAL */
+/* */
+/* COPYRIGHT International Business Machines Corp. 2012 */
+/* */
+/* p1 */
+/* */
+/* Object Code Only (OCO) source materials */
+/* Licensed Internal Code Source Materials */
+/* IBM HostBoot Licensed Internal Code */
+/* */
+/* The source code for this program is not published or otherwise */
+/* divested of its trade secrets, irrespective of what has been */
+/* deposited with the U.S. Copyright Office. */
+/* */
+/* Origin: 30 */
+/* */
+/* IBM_PROLOG_END_TAG */
#ifndef __ISTEPS_ISTEP16LIST_H
#define __ISTEPS_ISTEP16LIST_H
@@ -28,7 +28,7 @@
* @file istep16list.H
*
* IStep 16 Core Activate
- * IPL FLow Doc v1.01 (03/26/12)
+ * IPL FLow Doc v1.18 (10/18/12)
*
* 16.1 host_activate_master
* : Activate master core
diff --git a/src/include/usr/isteps/istep21list.H b/src/include/usr/isteps/istep21list.H
index e3418ddb8..2212ec181 100644
--- a/src/include/usr/isteps/istep21list.H
+++ b/src/include/usr/isteps/istep21list.H
@@ -1,25 +1,25 @@
-// IBM_PROLOG_BEGIN_TAG
-// This is an automatically generated prolog.
-//
-// $Source: src/include/usr/isteps/istep21list.H $
-//
-// IBM CONFIDENTIAL
-//
-// COPYRIGHT International Business Machines Corp. 2012
-//
-// p1
-//
-// Object Code Only (OCO) source materials
-// Licensed Internal Code Source Materials
-// IBM HostBoot Licensed Internal Code
-//
-// The source code for this program is not published or other-
-// wise divested of its trade secrets, irrespective of what has
-// been deposited with the U.S. Copyright Office.
-//
-// Origin: 30
-//
-// IBM_PROLOG_END
+/* IBM_PROLOG_BEGIN_TAG */
+/* This is an automatically generated prolog. */
+/* */
+/* $Source: src/include/usr/isteps/istep21list.H $ */
+/* */
+/* IBM CONFIDENTIAL */
+/* */
+/* COPYRIGHT International Business Machines Corp. 2012 */
+/* */
+/* p1 */
+/* */
+/* Object Code Only (OCO) source materials */
+/* Licensed Internal Code Source Materials */
+/* IBM HostBoot Licensed Internal Code */
+/* */
+/* The source code for this program is not published or otherwise */
+/* divested of its trade secrets, irrespective of what has been */
+/* deposited with the U.S. Copyright Office. */
+/* */
+/* Origin: 30 */
+/* */
+/* IBM_PROLOG_END_TAG */
#ifndef __ISTEPS_ISTEP21LIST_H
#define __ISTEPS_ISTEP21LIST_H
@@ -28,9 +28,13 @@
* @file istep21list.H
*
* IStep 21 Start Payload
- * IPL FLow Doc v1.01 (03/26/12)
+ * IPL FLow Doc v1.18 (10/18/12)
*
- * 21.1 host_start_payload
+ * 21.1 host_runtime_setup
+ * : Start Payload
+ * 21.2 host_verify_hdat
+ * : Start Payload
+ * 21.3 host_start_payload
* : Start Payload
*
* *****************************************************************
@@ -63,7 +67,23 @@ namespace INITSERVICE
},
{
- ISTEPNAME(21,01,"host_start_payload"),
+ ISTEPNAME(21,01,"host_runtime_setup"),
+ START_PAYLOAD::call_host_runtime_setup,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+ {
+ ISTEPNAME(21,02,"host_verify_hdat"),
+ START_PAYLOAD::call_host_verify_hdat,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+ {
+ ISTEPNAME(21,03,"host_start_payload"),
START_PAYLOAD::call_host_start_payload,
{
START_FN,
OpenPOWER on IntegriCloud
diff --git a/src/include/usr/isteps/istep06list.H b/src/include/usr/isteps/istep06list.H
index e86f07e2e..2a23fe81c 100644
--- a/src/include/usr/isteps/istep06list.H
+++ b/src/include/usr/isteps/istep06list.H
@@ -27,6 +27,7 @@
* @file istep6list.H
*
* list of functions called by HWAS (ISTEP 6) - "named isteps"
+ * IPL FLow Doc v1.18 (10/18/12)
*
* Please see the note in initsvcstructs.H for description of
* the ISTEPNAME macro.
@@ -53,8 +54,10 @@ namespace INITSERVICE
* 6. host_gard : Do Gard
* 7. host_cancontinue_clear : Clear deconfigured states
* 8. proc_revert_sbe_mcs_setup : Clean up MCS extent regs
* 9. proc_check_slave_sbe_seeprom_complete : Check Slave SBE Complete
* 10. proc_xmit_sbe : vSBE Init of Slave Chips
*
*/
const TaskInfo g_istep06[] = {
@@ -132,7 +135,25 @@ const TaskInfo g_istep06[] = {
}
},
{
- ISTEPNAME(06,09,"proc_check_slave_sbe_seeprom_complete"),
+ ISTEPNAME(06,09,"host_slave_sbe_config"),
+ SLAVE_SBE::call_host_slave_sbe_config,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+
+ {
+ ISTEPNAME(06,10,"host_sbe_start"),
+ SLAVE_SBE::call_host_sbe_start,
+ {
+ START_FN,
+ EXT_IMAGE,
+ }
+ },
+
+ {
+ ISTEPNAME(06,11,"proc_check_slave_sbe_seeprom_complete"),
SLAVE_SBE::call_proc_check_slave_sbe_seeprom_complete,
{
START_FN,
@@ -140,8 +161,8 @@ const TaskInfo g_istep06[] = {
}
},
{
- ISTEPNAME(06,10,"proc_xmit_sbe"),
- HWAS::proc_xmit_sbe,
+ ISTEPNAME(06,12,"proc_xmit_sbe"),
+ SLAVE_SBE::call_proc_xmit_sbe,
{
START_FN,
EXT_IMAGE,
@@ -53,8 +54,10 @@ namespace INITSERVICE
* 7. host_cancontinue_clear : Clear deconfigured states
* 8. proc_revert_sbe_mcs_setup : Clean up MCS extent regs
- * 9. proc_check_slave_sbe_seeprom_complete : Check Slave SBE Complete
- * 10. proc_xmit_sbe : vSBE Init of Slave Chips
+ * 9. host_slave_sbe_config
+ * 10. host_sbe_start
+ * 11. proc_check_slave_sbe_seeprom_complete : Check Slave SBE Complete
+ * 12. proc_xmit_sbe : vSBE Init of Slave Chips
*
*/
diff --git a/src/include/usr/isteps/istep18list.H b/src/include/usr/isteps/istep18list.H
index 69a282c8b..324fcaa39 100644
--- a/src/include/usr/isteps/istep18list.H
+++ b/src/include/usr/isteps/istep18list.H
@@ -28,9 +28,9 @@
* @file istep18list.H
*
* IStep 18 Establish System SMP
* IPL FLow Doc v1.08 (08/13/12)
*
- * 18.8 host_coalesce_host
+ * 18.10 host_coalesce_host
* : Create single host image
*
* *****************************************************************
@@ -125,9 +125,26 @@ namespace INITSERVICE
EXT_IMAGE,
}
},
+ {
+ ISTEPNAME(18,08,""),
+ NULL,
+ {
+ NONE,
+ EXT_IMAGE,
+ }
+ },
+ {
+
+ ISTEPNAME(18,09,""),
+ NULL,
+ {
+ NONE,
+ EXT_IMAGE,
+ }
+ },
{
- ISTEPNAME(18,08,"host_coalesce_host"),
+ ISTEPNAME(18,10,"host_coalesce_host"),
ESTABLISH_SYSTEM_SMP::call_host_coalesce_host,
{
START_FN,
@@ -28,9 +28,9 @@
*
* IStep 18 Establish System SMP
- * IPL FLow Doc v1.08 (08/13/12)
+ * IPL FLow Doc v1.18 (10/18/12)
*